### Name: simpgs
### Title: Plurigaussian Conditional Simulations
### Aliases: simpgs
### Keywords: classes

### ** Examples

# Acceptation function: an outcome is valid if the two samples designated #
# by their grid indices ('ranks') belong to the same connected component  #

accept <- function(db,iatt) 
{
                                        # Locations of wells in the grid #
  ranks = c(5021, 5081)

                                        # Perform the Connected components #
  a = db
  a = db.locate(a,iatt,"z")
  a = morpho(a,0.5,1.5,oper="cc")
  cc.rank = a$natt

                                        # Do all wells belong to same CC #
  ok = TRUE
  if (length(unique(a[ranks,cc.rank])) > 1) ok = FALSE
  if (ok) {
    vect = ifelse(a[,cc.rank] != a[ranks[1],cc.rank],0,1)
    db[,iatt] = ifelse(is.na(vect),0,vect)
  }
  res = list(ok=ok, db=db)
  res
}

# Perform a conditional simulation of facies #
nbsimu = 25
model  = model.create(vartype="Cubic",range=30)
rule   = rule.create(c("S","F1","F2"))
x1     = c(20,80,50)
x2     = c(50,50,50)
z1     = c(1,1,2)
data=db.create(x1=x1,x2=x2,z1=z1)
neigh = neigh.create(type=0)

grid = db.create(nx=c(100,100))
grid = simpgs(data,grid,rule=rule,model1=model,neigh=neigh,
       accept.fun=accept,nbsimu=nbsimu,nbtuba=1000)
grid = db.locerase(grid,"z")
grid = db.compare(grid,names="SimPGS*",fun="mean")
plot(grid,title="Connectivity probability",pos.legend=1)
plot(data,add=TRUE,name.post=1,pch=19,col=c("yellow","red")[z1])

rm(grid,model,rule,data,neigh,nbsimu,accept,x1,x2,z1)



